@@ -1,9 +1,11 @@
+from json.decoder import JSONDecodeError
 import confuse
 from trakt_scrobbler import logger
 from trakt_scrobbler.app_dirs import DATA_DIR
 from trakt_scrobbler.file_info import cleanup_guess
 from trakt_scrobbler.player_monitors.monitor import WebInterfaceMon
 from trakt_scrobbler.notifier import notify
+from trakt_scrobbler.utils import read_json, safe_request
 
 
 class PlexToken:
@@ -12,13 +14,24 @@ class PlexToken:
     TODO: Use some form of OS-provided encrypted storage
     """
     PATH = DATA_DIR / "plex_token.txt"
+    OLD_PATH = DATA_DIR / "plex_token.json"
 
     @property
     def data(self):
         try:
             return self.PATH.read_text(encoding="utf-8")
         except FileNotFoundError:
-            pass
+            return self.try_migrate_old_file()
+
+    def try_migrate_old_file(self):
+        token = read_json(self.OLD_PATH)
+        if not token:
+            # we really don't have the token
+            return None
+        # we got the token from old file- move to new
+        self.OLD_PATH.unlink()
+        self.data = token["token"]
+        return token["token"]
 
     @data.setter
     def data(self, token_data):
@@ -68,10 +81,17 @@ class PlexMon(WebInterfaceMon):
         self.media_info_cache = {}
 
     def get_data(self, url):
-        resp = self.sess.get(url)
+        resp = safe_request("get", {"url": url}, self.sess)
+        if resp is None:
+            return
         # TODO: If we get a 401, clear token and restart plex auth flow
         resp.raise_for_status()
-        data = resp.json()["MediaContainer"]
+        try:
+            data = resp.json()["MediaContainer"]
+        except JSONDecodeError:
+            logger.exception("Error with decoding")
+            logger.debug(resp.text)
+            return None
 
         if data["size"] <= 0:
             return None
@@ -84,7 +104,7 @@ class PlexMon(WebInterfaceMon):
             if metadata["User"]["title"] == self.config["scrobble_user"]:
                 return metadata
 
-    def update_status(self):
+    def _update_status(self):
         status_data = self.get_data(self.session_url)
         if not status_data:
             self.status = {}
@@ -94,6 +114,14 @@ class PlexMon(WebInterfaceMon):
         self.status["state"] = self.STATES.get(status_data["Player"]["state"], 0)
         self.status["media_info"] = self.get_media_info(status_data)
 
+    def update_status(self):
+        try:
+            return self._update_status()
+        except KeyError:
+            logger.exception("Weird key error in plex. Resetting status.")
+            self.status = {}
+            return
+
     def get_media_info(self, status_data):
         media_info = self.media_info_cache.get(status_data["ratingKey"])
         if not media_info:
